%global __requires_exclude GLIBC_PRIVATE

#one of valgrind internal library is not linked to libc. Not sure if it should be fixed or not (since all test don't pass anyway), so disable check for now
%define _disable_ld_no_undefined 1

# disable debug package, it can prevent valgrind for working properly
#define debug_package   %{nil}

# (blino) FIXME: reenable qt4 as soon as availble in cauldron
%bcond_with	qt4

Summary:	Tool for finding memory management bugs in programs
Name:		valgrind
Version:	3.10.1
%define subrel	1
Release:	%mkrel 2
License:	GPLv2+
Group:		Development/Tools
URL:		http://valgrind.org/
ExclusiveArch: %{ix86} x86_64 ppc ppc64 ppc64le s390x armv7hl aarch64
Obsoletes:	valgrind-plugins

# Only arches that are supported upstream as multilib and that fedora
# has multilib builds for should set build_multilib 1.
%ifarch x86_64
%global build_multilib 1
%else
%global build_multilib 0
%endif

# Note s390x doesn't have an openmpi port available.
%ifarch %{ix86} x86_64 ppc ppc64 ppc64le %{arm} aarch64
%global build_openmpi 1
%else
%global build_openmpi 0
%endif

# Don't run dwz or generate minisymtab, valgrind doesn't handle compressed
# DWARF very well and it might read its own vgpreload libraries. Generating
# minisymtabs doesn't really work for the staticly linked tools.
%define _find_debuginfo_dwz_opts %{nil}
%undefine _include_minidebuginfo

Source0: http://www.valgrind.org/downloads/valgrind-%{version}.tar.bz2

# From Fedora:

# Needs investigation and pushing upstream
Patch1: valgrind-3.9.0-cachegrind-improvements.patch

# KDE#211352 - helgrind races in helgrind's own mythread_wrapper
Patch2: valgrind-3.9.0-helgrind-race-supp.patch

# undef st_atime, st_mtime and st_ctime. Unknown why this is (still?) needed.
Patch3: valgrind-3.9.0-stat_h.patch

# Make ld.so supressions slightly less specific.
Patch4: valgrind-3.9.0-ldso-supp.patch

# KDE#342795 Internal glibc __GI_mempcpy call should be intercepted
Patch5: valgrind-3.10.1-mempcpy.patch

# KDE#343802 - s390x memcheck reports spurious conditional jump
Patch6: valgrind-3.10-s390-spechelper.patch

# KDE#342038, KDE#343732, KDE#343733, KDE#344007, KDE#344307
# mbind, get_mempolicy, set_mempolicy, flock, setgid, msgget, msgctl,
# msgrcv, msgsnd, accept4, mount, umount2
Patch7: valgrind-3.10.1-aarch64-syscalls.patch

# KDE#344007 ppc64 missing accept4 syscall
Patch8: valgrind-3.10.1-ppc64-accept4.patch

# KDE#344279 - syscall sendmmsg on arm64 (269) and ppc32/64 (349) unhandled
# KDE#344295 - syscall recvmmsg on arm64 (243) and ppc32/64 (343) unhandled
# KDE#344318 - socketcall should wrap recvmmsg and sendmmsg
Patch9: valgrind-3.10.1-send-recv-mmsg.patch

# Upstream valgrind svn r14530
Patch10: valgrind-3.10.1-glibc-version-check.patch

#END OF FEDORA PATCHES

Patch50: valgrind-3.10.1-CVE-2016-2226.patch
Patch51: valgrind-3.10.1-CVE-2016-4487_4488.patch
Patch52: valgrind-3.10.1-CVE-2016-4489.patch
Patch53: valgrind-3.10.1-CVE-2016-4490.patch
Patch54: valgrind-3.10.1-CVE-2016-4491.patch
Patch55: valgrind-3.10.1-CVE-2016-4492_4493.patch
Patch56: valgrind-3.10.1-CVE-2016-6131.patch
Patch57: valgrind-3.10.1-new_kernel.patch

BuildRequires:	glibc-static-devel
BuildRequires:	gdb
# (proyvind): build with support for OpenMP, boost & qt4 threads
BuildRequires:	libgomp-devel 
BuildRequires:	boost-devel
%if %{with qt4}
BuildRequires:	qt4-devel
%endif
Recommends:	gdb
%if %{build_openmpi}
BuildRequires: openmpi-devel >= 1.3.3
%endif

%description
When a program is run under Valgrind's supervision, all reads and
writes of memory are checked, and calls to malloc/new/free/delete are
intercepted. As a result, Valgrind can detect problems such as:

    * Use of uninitialised memory
    * Reading/writing memory after it has been free'd
    * Reading/writing off the end of malloc'd blocks
    * Reading/writing inappropriate areas on the stack
    * Memory leaks -- where pointers to malloc'd blocks are lost forever
    * Passing of uninitialised and/or unaddressible memory to system calls
    * Mismatched use of malloc/new/new [] vs free/delete/delete []

#--------------------------------------------------------------------

%package	devel
Summary:	%{summary}
Group:		%{group}
Conflicts:	%{name} < 3.6.1-3

%description	devel
Development files required to develop software using valgrind.

#--------------------------------------------------------------------

%package openmpi
Summary: OpenMPI support for valgrind
Group: Development/Tools
Requires: %{?scl_prefix}valgrind = %{version}-%{release}

%description openmpi
A wrapper library for debugging OpenMPI parallel programs with valgrind.
See the section on Debugging MPI Parallel Programs with Valgrind in the
Valgrind User Manual for details.
#--------------------------------------------------------------------
 
%prep
%setup -q -n %{name}-%{version}
%apply_patches

%build
# Convert the library paths with /lib or /lib64 in the suppressions to those
# with /usr/lib or /usr/lib64 due to the /usrmove .
perl -pi -e 's!obj:/lib!obj:/usr/lib!g' *.supp *.supp.in

# (From Fedora):
# Filter out some flags that cause lots of valgrind test failures.
# Also filter away -O2, valgrind adds it wherever suitable, but
# not for tests which should be -O0, as they aren't meant to be
# compiled with -O2 unless explicitely requested. Same for any -mcpu flag.
# Ideally we will change this to only be done for the non-primary build
# and the test suite.
OPTFLAGS="`echo " %{optflags} " | sed 's/ -m\(64\|3[21]\) / /g;s/ -fexceptions / /g;s/ -fstack-protector / / g;s/ -Wp,-D_FORTIFY_SOURCE=2 / /g;s/ -O2 / /g;s/ -mcpu=\([a-z0-9]\+\) / /g;s/^ //;s/ $//'`"
autoreconf -fi
%configure2_5x CC="$CC" CFLAGS="$OPTFLAGS" CXXFLAGS="$OPTFLAGS" \
  GDB=%{_bindir}/gdb

%make

# Ensure there are no unexpected file descriptors open,
# the testsuite otherwise fails.
cat > close_fds.c <<EOF
#include <stdlib.h>
#include <unistd.h>
int main (int argc, char *const argv[])
{
  int i, j = sysconf (_SC_OPEN_MAX);
  if (j < 0)
    exit (1);
  for (i = 3; i < j; ++i)
    close (i);
  execvp (argv[1], argv + 1);
  exit (1);
}
EOF
gcc $RPM_OPT_FLAGS -o close_fds close_fds.c

%install
# Don't strip (prevent valgrind from working properly, as explained in README_PACKAGERS)
export DONT_STRIP=1

# FIXME exporting DONT_STRIP=1 is causing some weird behavior with debug_package
# and causing it to not set DISABLE_DEBUG=1
export DISABLE_DEBUG=1

%makeinstall


%check
# Make sure a basic binary runs.
./vg-in-place /bin/true

# Make sure no extra CFLAGS leak through, the testsuite sets all flags
# necessary. See also configure above.
make check CFLAGS="" || :
# some tests are known to fail,
# just check no more tests are failing than Fedora ;)

echo ===============TESTING===================
./close_fds make regtest || :

# Make sure test failures show up in build.log
# Gather up the diffs (at most the first 20 lines for each one)
MAX_LINES=20
diff_files=`find . -name '*.diff' | sort`
if [ z"$diff_files" = z ] ; then
   echo "Congratulations, all tests passed!" >> diffs
else
   for i in $diff_files ; do
      echo "=================================================" >> diffs
      echo $i                                                  >> diffs
      echo "=================================================" >> diffs
      if [ `wc -l < $i` -le $MAX_LINES ] ; then
         cat $i                                                >> diffs
      else
         head -n $MAX_LINES $i                                 >> diffs
         echo "<truncated beyond $MAX_LINES lines>"            >> diffs
      fi
   done
fi
cat diffs
echo ===============END TESTING===============

%files
%doc README* AUTHORS FAQ.txt NEWS
%{_bindir}/*
%{_libdir}/%{name}
%{_mandir}/man1/*.1*

%files devel
%dir %{_includedir}/valgrind
%{_includedir}/valgrind/*
%{_libdir}/pkgconfig/%{name}.pc

%if %{build_openmpi}
%files openmpi
%defattr(-,root,root)
%dir %{_libdir}/valgrind
%{_libdir}/valgrind/libmpiwrap*.so
%endif



%changelog
* Sat Jul 08 2017 luigiwalser <luigiwalser> 3.10.1-2.1.mga5
+ Revision: 1109567
- add patches from ubuntu to fix:
  - CVE-2016-2226, CVE-2016-448[7-9], CVE-2016-449[0-3], CVE-2016-6131

* Fri Feb 20 2015 tv <tv> 3.10.1-2.mga5
+ Revision: 816078
- sync patches with FC

* Sat Jan 24 2015 tv <tv> 3.10.1-1.mga5
+ Revision: 812110
- new version
- sync patches with FC

* Wed Oct 22 2014 tv <tv> 3.10.0-3.mga5
+ Revision: 792474
- sync patches with FC

* Wed Oct 15 2014 umeabot <umeabot> 3.10.0-2.mga5
+ Revision: 743654
- Second Mageia 5 Mass Rebuild

  + tv <tv>
    - use %%global for req/prov exclude
    - autoconvert to new prov/req excludes
    - s/uggests:/Recommends:/

* Fri Sep 12 2014 tv <tv> 3.10.0-1.mga5
+ Revision: 674779
- 3.10.0 final

* Wed Sep 10 2014 tv <tv> 3.10.0-0.2.BETA2.mga5
+ Revision: 674502
- handle glibc-2.20

* Tue Sep 09 2014 tv <tv> 3.10.0-0.1.BETA2.mga5
+ Revision: 674079
- 3.10.0 BETA2
- don't run dwz or generate minisymtab
  (instead of disabling the whole debuginfo package)

* Wed Sep 03 2014 tv <tv> 3.10.0-0.1.BETA1.mga5
+ Revision: 671350
- 3.10.0 BETA1
- enables inlined frames in stacktraces

* Mon Sep 01 2014 luigiwalser <luigiwalser> 3.9.0-9.svn20140829r14384.mga5
+ Revision: 670358
- remove epoch from requires for valgrind-openmpi

* Sun Aug 31 2014 tv <tv> 3.9.0-8.svn20140829r14384.mga5
+ Revision: 669841
- fix group
- enable openmpi support

* Fri Aug 29 2014 tv <tv> 3.9.0-7.svn20140829r14384.mga5
+ Revision: 669299
- update to upstream svn r14384

* Wed Aug 27 2014 tv <tv> 3.9.0-7.svn20140827r14371.mga5
+ Revision: 668833
- update to upstream svn r14370

* Wed Aug 27 2014 tv <tv> 3.9.0-7.svn20140809r14250.mga5
+ Revision: 668592
- fix default suppresions file location

* Tue Aug 12 2014 tv <tv> 3.9.0-6.svn20140809r14250.mga5
+ Revision: 661862
- new release

* Sat Aug 02 2014 tv <tv> 3.9.0-6.svn20140718r14176.mga5
+ Revision: 659299
- new snapshot
- sync patches with RH

* Fri Feb 28 2014 tv <tv> 3.9.0-6.mga5
+ Revision: 597955
- sync patches with RH:
  o Add upstream fixes to valgrind-3.9.0-timer_create.patch
  o Add valgrind-3.9.0-glibc-2.19.patch
  o Add valgrind-3.9.0-s390-dup3.patch
  o Add valgrind-3.9.0-timer_create.patch

* Mon Feb 17 2014 tmb <tmb> 3.9.0-5.mga5
+ Revision: 593950
- rebuild with new glibc

* Sun Feb 09 2014 pterjan <pterjan> 3.9.0-3.mga5
+ Revision: 587806
- Fix spec

  + tv <tv>
    - sync patches with RH

* Sun Feb 09 2014 tmb <tmb> 3.9.0-2.mga5
+ Revision: 587781
- support glibc 2.19 (P7, Arch)
- rebuild for new glibc

* Tue Nov 05 2013 tv <tv> 3.9.0-1.mga4
+ Revision: 549603
- new release 3.9.0
- package NEWS
- kill patches that are now upstream
- sync patches with FC

* Mon Oct 21 2013 umeabot <umeabot> 3.8.1-14.mga4
+ Revision: 539058
- Mageia 4 Mass Rebuild

* Fri Oct 04 2013 tv <tv> 3.8.1-13.mga4
+ Revision: 491272
- sync with FC:
  o rename patch 50 a 52
  o filter out -mcpu= so tests are compiled with the right flags (rhbz#996927)
  o implement SSE4 MOVNTDQA insn
  o fix power_ISA2_05 testcase
  o fix ppc32 make check build
  o add valgrind-3.8.1-mmxext.patch

* Fri Oct 04 2013 shlomif <shlomif> 3.8.1-12.mga4
+ Revision: 491263
- Get rid of trailing whitespace in the spec
- Fix for RH#1011713. Broke some tests.

* Wed Aug 21 2013 tv <tv> 3.8.1-11.mga4
+ Revision: 469105
- Allow building against glibc 2.18 (rhbz#999169)

* Wed Aug 21 2013 tv <tv> 3.8.1-10.mga4
+ Revision: 468611
- sync patches with FC

* Mon Jul 15 2013 tv <tv> 3.8.1-9.mga4
+ Revision: 454891
- sync patches with RH

* Mon Jul 08 2013 fwang <fwang> 3.8.1-8.mga4
+ Revision: 451225
- rebuild for new boost

  + tv <tv>
    - sync patches with FC

* Mon May 27 2013 tv <tv> 3.8.1-7.mga4
+ Revision: 428964
- sync patches with FC

* Mon Jan 14 2013 umeabot <umeabot> 3.8.1-6.mga3
+ Revision: 385224
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 cjw <cjw> 3.8.1-5.mga3
+ Revision: 339934
- patch103: allow to build with glibc 2.17

* Fri Dec 14 2012 tv <tv> 3.8.1-4.mga3
+ Revision: 330586
- rebuild for new gdb

* Sun Nov 18 2012 tv <tv> 3.8.1-3.mga3
+ Revision: 319493
- sync patches with FC (after fixing them trying to patch .orig files...)

  + malo <malo>
    - update RPM group

* Thu Oct 11 2012 tv <tv> 3.8.1-2.mga3
+ Revision: 304680
- sync patches with FC

* Wed Sep 26 2012 tv <tv> 3.8.1-1.mga3
+ Revision: 297921
- new release
- sync with FC patches

* Mon Aug 27 2012 tv <tv> 3.8.0-4.mga3
+ Revision: 284624
- new release

* Tue Aug 21 2012 tv <tv> 3.8.0-3.mga3
+ Revision: 282942
- patch 100: fix a crash with mini debug info

* Mon Aug 20 2012 blino <blino> 3.8.0-2.mga3
+ Revision: 282510
- add valgrind-3.8.0-find-buildid.patch workaround from Fedora (RH#849435 KDE#305431)

* Mon Aug 13 2012 tv <tv> 3.8.0-1.mga3
+ Revision: 281166
- drop patch  (what comment said was merged)
- drop merged glibc-2.16 patch
- drop now useless automake patch
- drop merged FC patches
- add new patches from FC
- add one patch from FC (on i?86 prefer to use CFI over %%ebp unwinding, as GCC
  4.6+ defaults to -fomit-frame-pointer)
- like FC, filter out some compilation flags (getting rid of new cloberring
  issues due to -fPIC on x86_64)
- fix install

* Sat Aug 11 2012 blino <blino> 3.7.0-5.mga3
+ Revision: 280480
- add patches from Fedora (and upstream valgrind) to handle dwz DWARF compressor output

* Wed Jul 25 2012 shlomif <shlomif> 3.7.0-4.mga3
+ Revision: 274227
- Convert paths to /usr/lib* instead of /lib* in the suppressions.
  This is another fallout of the /usr-move.

* Sat Jul 21 2012 shlomif <shlomif> 3.7.0-3.mga3
+ Revision: 273153
- Add a blurb to the patch
- New release for glibc-2.16.x.
  1. Fix build with new automake.
  2. Update the valgrind package to accept building against 2.16 (with a patch
  derived from the svn).
  3. Fix problems with unpacked files.
  4. Put a symlink to a place that valgrind is looking for.

* Wed Dec 21 2011 shlomif <shlomif> 3.7.0-1.mga2
+ Revision: 185524
- Cancel make regtest because it hangs.

  + fwang <fwang>
    - sync with mandriva package

* Thu Oct 27 2011 shlomif <shlomif> 3.6.1-5.mga2
+ Revision: 158760
- Applied patches to build against kernel-3.x and glibc-2.14.x

* Wed Jun 22 2011 ahmad <ahmad> 3.6.1-4.mga2
+ Revision: 111971
- Add conflicts to ease updates after the -devel split (from tv)
- Re-enable building with qt4
- Only run autoreconf when building with qt4
- Drop unapplied patch3

* Tue Jun 07 2011 dmorgan <dmorgan> 3.6.1-3.mga2
+ Revision: 101519
- Provide devel subpackage  ( partial merge of mdv commit 659516)

* Sun May 15 2011 pterjan <pterjan> 3.6.1-2.mga1
+ Revision: 99037
- Rebuild for fixed find-requires

* Sat Apr 16 2011 pterjan <pterjan> 3.6.1-1.mga1
+ Revision: 86603
- Update to 3.6.1

* Tue Jan 11 2011 blino <blino> 3.6.0-2.mga1
+ Revision: 6503
- do not build with qt4 support for now
- remove versions in comments
- imported package valgrind


* Wed Nov 03 2010 Paulo Andrade <pcpa@mandriva.com.br> 3.6.0-1mdv2011.0
+ Revision: 593038
- Update to valgrind 3.6.0

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - build with support for OpenMP, boost & qt4 threads

* Mon Dec 07 2009 Paulo Andrade <pcpa@mandriva.com.br> 3.5.0-2mdv2010.1
+ Revision: 474521
- Correct valgrind to work with glibc-2.11.

* Wed Aug 26 2009 Eugeni Dodonov <eugeni@mandriva.com> 3.5.0-1mdv2010.0
+ Revision: 421314
- updated to 3.5.0

* Thu Jun 25 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 3.4.1-3mdv2010.0
+ Revision: 389173
- add wildcards after GLIBC_VERSION to match any library micro versions as well (P4 from Fedora)
- redirect x86_64 ld.so strlen early (P3, RH bug #495645)

* Tue Jun 02 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 3.4.1-2mdv2010.0
+ Revision: 382232
- Rebuild with newer glibc (#51374).

* Thu Mar 05 2009 Frederic Crozat <fcrozat@mandriva.com> 3.4.1-1mdv2009.1
+ Revision: 348875
- Release 3.4.1
- Regenerate patch0
- Remove patch1 (merged upstream)

* Thu Jan 15 2009 Frederic Crozat <fcrozat@mandriva.com> 3.4.0-1mdv2009.1
+ Revision: 329847
- Release 3.4.0
- Remove patches 3, 8 (merged upstream)
- Regenerate patches 0 & 1

* Mon Jun 30 2008 Frederic Crozat <fcrozat@mandriva.com> 3.3.1-2mdv2009.0
+ Revision: 230240
- Update patch8 with upstream fix

* Thu Jun 26 2008 Frederic Crozat <fcrozat@mandriva.com> 3.3.1-1mdv2009.0
+ Revision: 229225
- Release 3.3.1
- Remove patches 4, 5, 6, 7 (merged upstream)
- Don't regenerate debug package, all debug info should stay in valgrind binaries

* Fri May 30 2008 Paulo Andrade <pcpa@mandriva.com.br> 3.3.0-5mdv2009.0
+ Revision: 213483
- Don't supress warnings only if the binary has been explicitly linked
  with libraries at /usr/X11*/lib*.

  + Frederic Crozat <fcrozat@mandriva.com>
    - Rebuild with glibc 4.3 / glibc 2.8
    - run make test in check section
    - Patch0 (Fedora): add cachegrind improvement
    - Patch1 (Fedora): fix pkgconfig file (RH bug #213149)
    - Patch2 (Fedora): fix openat handling (RH bug #208097)
    - Patch3 (Fedora): suppress pthread_barrier_wait in helgrind
    - Patch4 (Fedora): add suppression for glibc 2.7
    - Patch5 (Fedora): add support for glibc 2.8
    - Patches6, 7 (Fedora): add more syscalls
    - Patch8: fix malloc_free_fill test when glibc >= 2.7

* Thu Feb 21 2008 Adam Williamson <awilliamson@mandriva.org> 3.3.0-3mdv2008.1
+ Revision: 173469
- suggests gdb (#37755)

* Thu Feb 14 2008 Adam Williamson <awilliamson@mandriva.org> 3.3.0-2mdv2008.1
+ Revision: 167680
- new license policy
- drop bogus doc install hacks
- buildrequires gdb (#37739)
- spec clean
- drop Source1 (it's not actually used)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Tue Dec 18 2007 trem <trem@mandriva.org> 3.3.0-1mdv2008.1
+ Revision: 131903
- update to 3.3.0
- remove patch for glibc-2.6

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Aug 06 2007 Olivier Blin <oblin@mandriva.com> 3.2.3-2mdv2008.0
+ Revision: 59231
- use generic man page extension in files list (for lzma)
- add glibc-2.6 support (patch from Gentoo)


* Fri Mar 16 2007 Laurent Montel <lmontel@mandriva.com> 3.2.3-1mdv2007.1
+ Revision: 144737
- 3.2.3

* Sat Jan 13 2007 Michael Scherer <misc@mandriva.org> 3.2.1-1mdv2007.1
+ Revision: 108323
- update to 3.2.1, fix illegal instruction on current libstdc++ on x86_64
- Import valgrind

* Sat Jun 17 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.2.0-2mdv2007.0
- obsoletes valgrind-plugins

* Wed Jun 14 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.2.0-1mdv2007.0
- new version
- rpmbuildupdate aware
- spec cleanup
- move doc file in doc directory

* Sat Apr 29 2006 Jerome Soyer <saispo@mandriva.org> 3.1.1-1mdk
- New release 3.1.1

* Fri Feb 17 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 3.1.0-2mdk
- enable build for ppc

* Thu Dec 01 2005 Laurent MONTEL <lmontel@mandriva.com> 3.1.0-1mdk
- 3.1.0

* Tue Sep 06 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 3.0.1-1mdk
- 3.0.1

* Fri Aug 05 2005 Laurent MONTEL <lmontel@mandriva.com> 3.0.0-1mdk
- 3.0.0

* Thu Mar 24 2005 Laurent MONTEL <lmontel@mandrakesoft.com> 2.4.0-1mdk
- 2.4.0

* Wed Jan 19 2005 Laurent MONTEL <lmontel@mandrakesoft.com> 2.2.0-2mdk
- Remove calltree from this package create new package valgrind-plugins and put callgrind into (because we can't compile callgrind without valgrind)

* Sat Sep 04 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.2.0-1mdk
- 2.2.0

* Thu Jul 22 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.2-1mdk
- 2.1.2 (see http://developer.kde.org/~sewardj/docs-2.0.0/NEWS.txt)

* Fri Apr 23 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.1-3mdk
- Add calltree plugins for kcachegrind (kdesdk)

* Tue Apr 20 2004 Per yvind Karlsen <peroyvind@linux-mandrake.com> 2.1.1-2mdk
- fix buildrequires
- use %%configure macro
- update url
- drop patches that wasn't applied

* Wed Mar 31 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.1-1mdk
- new version

* Wed Mar 31 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.0-3mdk
- Don't package twice manual.html bug #9314

